<?php
/**
 * Theme Functions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Sterling Theme
 */

/*-----------------------------------------------------------------------------------*/
/* DO NOT EDIT THIS FILE. THE SKY MAY FALL.
/*-----------------------------------------------------------------------------------*/
// Define File Directores.
if ( function_exists( 'wp_get_theme' ) ) :
	$theme_object 	= wp_get_theme();
	$theme_name 	= $theme_object->name;
endif;

// Define Theme Constants.
define( 'TT_FUNCTIONS', 				get_template_directory() . '/framework' );
define( 'TT_GLOBAL', 					get_template_directory() . '/framework/global' );
define( 'TT_ADMIN', 					get_template_directory() . '/framework/admin' );
define( 'TT_STERLING', 					get_template_directory() . '/framework/theme-specific' );
define( 'TT_EXTENDED', 					get_template_directory() . '/framework/extended' );
define( 'TT_CONTENT', 					get_template_directory() . '/framework/content' );
define( 'TT_JS', 						get_template_directory_uri() . '/framework/js' );
define( 'TT_FRAMEWORK', 				get_template_directory_uri() . '/framework' );
define( 'TT_CSS', 						get_template_directory_uri() . '/css/' );
define( 'TT_HOME', 						get_template_directory_uri() );
define( 'TT', 							get_template_directory() . '/framework/truethemes' );
define( 'TIMTHUMB_SCRIPT',				get_template_directory_uri() . '/framework/extended/timthumb/timthumb.php' );
define( 'TIMTHUMB_SCRIPT_MULTISITE', 	get_template_directory_uri() . '/framework/extended/timthumb/timthumb.php' );
add_action('tgmpa_register', 'sterling_include_required_plugins');

/**
 * Include plugins
 **/
if ( !function_exists('sterling_include_required_plugins') ) {
	function sterling_include_required_plugins() {

		$plugins = array(
			array(
				'name'               => esc_html__('Gutenberg Blocks Collection', 'sterling'), // The plugin name
				'slug'               => 'qodeblock', // The plugin slug (typically the folder name)
				'required'           => true, // If false, the plugin is only 'recommended' instead of required
				'version'            => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
				'external_url'       => '', // If set, overrides default API URL and points to an external URL
			),
		);

		// Change this to your theme text domain, used for internationalising strings

		/**
		 * Array of configuration settings. Amend each line as needed.
		 * If you want the default strings to be available under your own theme domain,
		 * leave the strings uncommented.
		 * Some of the strings are added into a sprintf, so see the comments at the
		 * end of each line for what each argument will be.
		 */
		$config = array(
			'domain'       => 'sterling',                    // Text domain - likely want to be the same as your theme.
			'default_path' => '',                            // Default absolute path to pre-packaged plugins
			'menu'         => 'tgmpa-install-plugins',    // Menu slug
			'has_notices'  => true,                        // Show admin notices or not
			'is_automatic' => true,                        // Automatically activate plugins after installation or not
			'message'      => '',                            // Message to output right before the plugins table
			'strings'      => array(
				'page_title'                      => esc_html__('Install Required Plugins', 'sterling'),
				'menu_title'                      => esc_html__('Install Plugins', 'sterling'),
				'installing'                      => esc_html__('Installing Plugin: %s', 'sterling'),
				// %1$s = plugin name
				'oops'                            => esc_html__('Something went wrong with the plugin API.', 'sterling'),
				'notice_can_install_required'     => _n_noop('This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'sterling'),
				// %1$s = plugin name(s)
				'notice_can_install_recommended'  => _n_noop('This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'sterling'),
				// %1$s = plugin name(s)
				'notice_cannot_install'           => _n_noop('Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'sterling'),
				// %1$s = plugin name(s)
				'notice_can_activate_required'    => _n_noop('The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'sterling'),
				// %1$s = plugin name(s)
				'notice_can_activate_recommended' => _n_noop('The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'sterling'),
				// %1$s = plugin name(s)
				'notice_cannot_activate'          => _n_noop('Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'sterling'),
				// %1$s = plugin name(s)
				'notice_ask_to_update'            => _n_noop('The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'sterling'),
				// %1$s = plugin name(s)
				'notice_cannot_update'            => _n_noop('Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'sterling'),
				// %1$s = plugin name(s)
				'install_link'                    => _n_noop('Begin installing plugin', 'Begin installing plugins', 'sterling'),
				'activate_link'                   => _n_noop('Activate installed plugin', 'Activate installed plugins', 'sterling'),
				'return'                          => esc_html__('Return to Required Plugins Installer', 'sterling'),
				'plugin_activated'                => esc_html__('Plugin activated successfully.', 'sterling'),
				'complete'                        => esc_html__('All plugins installed and activated successfully. %s', 'sterling'),
				// %1$s = dashboard link
				'nag_type'                        => 'updated'
				// Determines admin notice type - can only be 'updated' or 'error'
			)
		);

		tgmpa($plugins, $config);
	}
}

/*-----------------------------------------------------------------------------------*/
/* Register Style for Admin
/*-----------------------------------------------------------------------------------*/

function sterling_register_admin_css() {
	wp_enqueue_style( 'sterling-font', 'https://fonts.googleapis.com/css?family=Open+Sans:400,600,300' );
	wp_enqueue_style( 'sterling-admin', get_template_directory_uri() . '/css/admin.min.css' );
}
add_action( 'admin_enqueue_scripts', 'sterling_register_admin_css' );

/*-----------------------------------------------------------------------------------*/
/* Fire up the Framework
/*-----------------------------------------------------------------------------------*/
/*
 * This is essentially the theme's functions.php file
 * many functions are in this file :)
 *
 */


require_once( dirname( __FILE__ ) . '/framework/framework_init.php' );


require get_template_directory() . '/vendor/autoload.php';


/**
 * Initialize the plugin tracker
 *
 * @return void
 */
function appsero_init_tracker_sterling() {

	if ( ! class_exists( 'Appsero\Client' ) ) {
		require_once get_template_directory() . '/vendor/appsero/client/src/Client.php';
	}

	$client = new \Appsero\Client( '8f7dcdc5-6994-4d12-902a-cd95d2ffa51d', 'Sterling', __FILE__ );

	// Active insights
	$client->insights()->init();

	// Active automatic updater
	$client->updater();

}

appsero_init_tracker_sterling();



/*-----------------------------------------------------------------------------------*/
/* WP_DEBUG + PHP Error Reporting
/*-----------------------------------------------------------------------------------*/
//Some plugins such as wpcu3er will disable PHP error reporting,
//therefore we must make sure it is turn on if WP_DEBUG is set to true.
if(defined('WP_DEBUG') == 1 || WP_DEBUG == true){
$error_setting = ini_get("display_errors");
	if($error_setting == '0'){
		ini_set('display_errors', '1');
	}
}
//if PHP error reporting is enabled we will only ALLOW PHP fatal error, syntax error, parse errors etc to show only.
$php_error_setting = ini_get("display_errors");
	if($php_error_setting == '1'){
	    //reference to http://www.php.net/manual/en/errorfunc.constants.php
		error_reporting(E_ALL & ~E_STRICT & ~E_NOTICE & ~E_WARNING & ~ E_DEPRECATED & ~ E_USER_NOTICE);
}
/*-----------------------------------------------------------------------------------*/
/* Automatic Plugin Updates (https://kernl.us/documentation)
/*-----------------------------------------------------------------------------------*/
if(is_admin()){ //do this only in admin
	require 'theme_update_check.php';
	$licence_key = get_option('st_item_purchase_code');
	//uncomment to see license key
	//print_r($licence_key);
	if(!empty($licence_key)){
		$MyUpdateChecker = new ThemeUpdateChecker(
		    'Sterling',
		    'https://kernl.us/api/v1/theme-updates/56f5758f20b0dbfb4eaa1da0/'
		);
		$MyUpdateChecker->purchaseCode = $licence_key;
	}
}

@ini_set( 'upload_max_size' , '64M' );
@ini_set( 'post_max_size', '64M');
@ini_set( 'memory_limit', '256M' );



function sterling_set_script( $scripts, $handle, $src, $deps = array(), $ver = false, $in_footer = false ) {
	$script = $scripts->query( $handle, 'registered' );

	if ( $script ) {
		// If already added
		$script->src  = $src;
		$script->deps = $deps;
		$script->ver  = $ver;
		$script->args = $in_footer;

		unset( $script->extra['group'] );

		if ( $in_footer ) {
			$script->add_data( 'group', 1 );
		}
	} else {
		// Add the script
		if ( $in_footer ) {
			$scripts->add( $handle, $src, $deps, $ver, 1 );
		} else {
			$scripts->add( $handle, $src, $deps, $ver );
		}
	}
}



function sterling_replace_scripts( $scripts ) {
	$assets_url = TT_HOME . '/framework/js/';

	sterling_set_script( $scripts, 'jquery-migrate', $assets_url . 'jquery-migrate.min.js', array(), '1.4.1-wp' );
	sterling_set_script( $scripts, 'jquery', false, array( 'jquery-core', 'jquery-migrate' ), '1.12.4-wp' );
}

add_action( 'wp_default_scripts', 'sterling_replace_scripts' );