<?php

/**
 * Sterling functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Sterling
 */

defined('STERLING_T_URI') or define('STERLING_T_URI', get_template_directory_uri());
defined('STERLING_T_PATH') or define('STERLING_T_PATH', get_template_directory());

require_once ABSPATH . 'wp-admin/includes/plugin.php';

require_once STERLING_T_PATH . '/include/class-tgm-plugin-activation.php';
require_once STERLING_T_PATH . '/include/custom-header.php';
require_once STERLING_T_PATH . '/include/actions-config.php';
require_once STERLING_T_PATH . '/include/helper-function.php';
require_once STERLING_T_PATH . '/include/customizer.php';
require STERLING_T_PATH . '/vendor/autoload.php';


/**
 * Initialize the plugin tracker
 *
 * @return void
 */
function appsero_init_tracker_sterling() {

	if ( ! class_exists( 'Appsero\Client' ) ) {
		require_once __DIR__ . '/vendor/appsero/client/src/Client.php';
	}

	$client = new \Appsero\Client( '8f7dcdc5-6994-4d12-902a-cd95d2ffa51d', 'Sterling', __FILE__ );

	// Active insights
	$client->insights()->init();

	// Active automatic updater
	$client->updater();

}

appsero_init_tracker_sterling();

if (!function_exists('sterling_setup')) :
	function sterling_setup()
	{
		register_nav_menus(array('primary-menu' => esc_html__('Primary menu', 'sterling')));
		load_theme_textdomain('sterling', get_template_directory() . '/languages');
		add_theme_support('automatic-feed-links');
		add_theme_support('title-tag');
		add_theme_support('post-thumbnails');
		add_theme_support('html5', array('search-form', 'comment-form', 'comment-list', 'gallery', 'caption'));
		add_theme_support('post-formats', array(
			'aside',
			'gallery',
			'link',
			'image',
			'quote',
			'status',
			'video',
			'audio',
			'chat'
		));

		add_theme_support('woocommerce');

		// Set up the WordPress core custom background feature.
		add_theme_support('custom-background', apply_filters('sterling_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		)));

		// Add theme support for selective refresh for widgets.
		add_theme_support('customize-selective-refresh-widgets');
		add_theme_support('custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		));
	}
endif;

add_action('after_setup_theme', 'sterling_setup');

// Disable REST API link tag
remove_action('wp_head', 'rest_output_link_wp_head', 10);

if (!function_exists('sterling_woocommerce_template_loop_product_title')) {

	/**
	 * Show the product title in the product loop. By default this is an H2.
	 */
	function sterling_woocommerce_template_loop_product_title()
	{
		echo '<h4 class="woocommerce-loop-product--title">' . get_the_title() . '</h4>';
	}
}

add_action('woocommerce_shop_loop_item_title', 'sterling_woocommerce_template_loop_product_title', 20);


if (function_exists('aheto')) {
	function sterling_theme_options($theme_tabs)
	{
		$theme_tabs = [
			'sterling_shop' => [
				'icon'  => 'dashicons dashicons-admin-generic pink-color',
				'title' => esc_html__('Shop Options', 'sterling'),
				'desc'  => esc_html__('This tab contains the theme shop options.', 'sterling'),
				'file'  => STERLING_T_PATH . '/include/shop-options.php',
			],
		];
		return $theme_tabs;
	}
}

add_filter('aheto_theme_options', 'sterling_theme_options', 10, 2);


$shortcodes_dir = get_template_directory() . '/aheto';
$files = glob($shortcodes_dir . '/*/controllers/*.php');
foreach ($files as $file) {
	require_once($file);
}

function sterling_add_dependency( $id, $args = array(), $shortcode ) {
	if ( is_array( $id ) ) {
			foreach ( $id as $slug ) {
					$param = (array)$shortcode->depedency[$slug]['template'];
					$shortcode->depedency[$slug]['template'] = array_merge($args, $param );
			}
	} else {
			$param = (array)$shortcode->depedency[$id]['template'];
			$shortcode->depedency[$id]['template'] = array_merge($args, $param );
	}
	return;
}

add_filter( 'aheto_template_kit_category', function () {
  return 'sterling';
} );


function sterling_export_data() {
    if ( class_exists( 'Aheto\Template_Kit\API' ) ) {

        $aheto_api = new Aheto\Template_Kit\API;

        $endpoint = '/aheto/v1/getThemeTemplate/9182';


        $response = $aheto_api->get_demodata( $endpoint, false, false );
        return $response;
    }
}

add_filter( 'export_data', 'sterling_export_data', 10 );



add_filter( 'aheto_wizard', function () {
	return true;
} );