<?php

require_once ABSPATH . 'wp-admin/includes/plugin.php';

/**
 * Create custom html structure for comments
 */
if (!function_exists('sterling_comment')) {
	function sterling_comment($comment, $args, $depth)
	{

		$GLOBALS['comment'] = $comment;

		switch ($comment->comment_type):
			case 'pingback':
			case 'trackback': ?>
				<div class="pinback">
					<span class="pin-title"><?php esc_html_e('Pingback: ', 'sterling'); ?></span><?php comment_author_link(); ?>
					<?php edit_comment_link(esc_html__('(Edit)', 'sterling'), '<span class="edit-link">', '</span>'); ?>

				<?php
				break;
			default:
				// generate comments
				?>
					<div <?php comment_class('sterling-blog--single__comments-item'); ?> id="li-comment-<?php comment_ID(); ?>">
						<div id="comment-<?php comment_ID(); ?>" class="sterling-blog--single__comments-item-wrap">
							<div class="sterling-blog--single__comments-content">
								<span class="person-img">
									<?php echo get_avatar($comment, '80', '', '', array('class' => 'img-person')); ?>
								</span>
								<div class="comment-content">
									<div class="author-wrap">
										<div class="author">
											<?php comment_author(); ?>
										</div>
										<?php comment_reply_link(
											array_merge(
												$args,
												array(
													'reply_text' => esc_html__('Reply', 'sterling'),
													'after'      => '',
													'depth'      => $depth,
													'max_depth'  => $args['max_depth']
												)
											)
										); ?>
									</div>

									<div class="comment-text">
										<?php comment_text(); ?>
									</div>

									<div class="comment-date">
										<?php comment_date(get_option('date_format')); ?>
									</div>
								</div>
							</div>
						</div>
		<?php
				break;
		endswitch;
	}
}


/**
 * Filter for excerpt more string
 */

if (!function_exists('sterling_excerpt_more')) {
	function sterling_excerpt_more()
	{
		return ' ...';
	}

	add_filter('excerpt_more', 'sterling_excerpt_more');
}


/**
 * Header template
 */

if (!function_exists('sterling_main_header_html')) {
	function sterling_main_header_html()
	{

		$active_plugin = function_exists('aheto') ? true : false;
		$template_name = $active_plugin ? 'aheto' : 'theme';

		get_template_part('template-parts/' . $template_name . '-header');
	}
}

add_action('sterling_main_header', 'sterling_main_header_html');



/**
 * Footer template
 */

if (!function_exists('sterling_main_footer_html')) {
	function sterling_main_footer_html()
	{

		$active_plugin = function_exists('aheto') ? true : false;
		$template_name = $active_plugin ? 'aheto' : 'theme';

		get_template_part('template-parts/' . $template_name . '-footer');
	}
}


add_action('sterling_main_footer', 'sterling_main_footer_html');


/*
 * Check woocommerce page
 */
if (!function_exists('sterling_is_realy_woocommerce_page')) {
	function sterling_is_realy_woocommerce_page()
	{
		if (function_exists("is_woocommerce") && is_woocommerce()) {
			return true;
		}
		$woocommerce_keys = array(
			"woocommerce_shop_page_id",
			"woocommerce_terms_page_id",
			"woocommerce_cart_page_id",
			"woocommerce_checkout_page_id",
			"woocommerce_pay_page_id",
			"woocommerce_thanks_page_id",
			"woocommerce_myaccount_page_id",
			"woocommerce_edit_address_page_id",
			"woocommerce_view_order_page_id",
			"woocommerce_change_password_page_id",
			"woocommerce_logout_page_id",
			"woocommerce_lost_password_page_id"
		);

		foreach ($woocommerce_keys as $wc_page_id) {
			if (get_the_ID() == get_option($wc_page_id, 0)) {
				return true;
			}
		}
		return false;
	}
}
